@@ -92,7 +92,7 @@ class BaseJAAQLController:
         super().__init__()
         self.app = Flask(__name__, instance_relative_config=True)
         self.app.config[FLASK__json_sort_keys] = False
-        self.app.config[FLASK__max_content_length] = 1024 * 100 * 2  # 2 MB
+        self.app.config[FLASK__max_content_length] = 1024 * 1024 * 2  # 2 MB
         self._init_error_handlers(self.app)
         self.model = model
         self.do_profiling = do_profiling
@@ -398,6 +398,11 @@ class BaseJAAQLController:
         def wrap_func(view_func):
             @wraps(view_func)
             def routed_function(view_func_local):
+                if not self.model.has_installed and not route.startswith('/internal'):
+                    resp = Response("Still installing. Be patient", status=HTTPStatus.SERVICE_UNAVAILABLE)
+                    self._cors(resp)
+                    return resp
+
                 request_id = uuid.uuid4()
                 self.perform_profile(request_id, route=route, method=request.method)
                 start_time = datetime.now()
